@@ -4,7 +4,7 @@ module Doorkeeper
   module Rake
     class << self
       def load_tasks
-        glob = File.join(File.absolute_path(__dir__), 'rake', '*.rake')
+        glob = File.join(File.absolute_path(__dir__), "rake", "*.rake")
         Dir[glob].each do |rake_file|
           load rake_file
         end
